@@ -52,7 +52,7 @@ class SimpleSAML_SessionHandlerPHP extends SimpleSAML_SessionHandler
 
         if ($previous_session) {
             if (session_name() === $this->cookie_name || $this->cookie_name === null) {
-                SimpleSAML\Logger::warning(
+                SimpleSAML_Logger::warning(
                     'There is already a PHP session with the same name as SimpleSAMLphp\'s session, or the '.
                     "'session.phpsession.cookiename' configuration option is not set. Make sure to set ".
                     "SimpleSAMLphp's cookie name with a value not used by any other applications."
