@@ -7,7 +7,7 @@
  * and authenticates users against this array.
  *
  * @author Dyonisius Visser, TERENA.
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 class sspmod_authcrypt_Auth_Source_Hash extends sspmod_core_Auth_UserPassBase {
 
@@ -29,12 +29,12 @@ class sspmod_authcrypt_Auth_Source_Hash extends sspmod_core_Auth_UserPassBase {
 		assert('is_array($info)');
 		assert('is_array($config)');
 
-		/* Call the parent constructor first, as required by the interface. */
+		// Call the parent constructor first, as required by the interface
 		parent::__construct($info, $config);
 
 		$this->users = array();
 
-		/* Validate and parse our configuration. */
+		// Validate and parse our configuration
 		foreach ($config as $userpass => $attributes) {
 			if (!is_string($userpass)) {
 				throw new Exception('Invalid <username>:<passwordhash> for authentication source ' .
@@ -50,7 +50,7 @@ class sspmod_authcrypt_Auth_Source_Hash extends sspmod_core_Auth_UserPassBase {
 			$passwordhash = $userpass[1];
 
 			try {
-				$attributes = SimpleSAML_Utilities::parseAttributes($attributes);
+				$attributes = SimpleSAML\Utils\Attributes::normalizeAttributesArray($attributes);
 			} catch(Exception $e) {
 				throw new Exception('Invalid attributes for user ' . $username .
 					' in authentication source ' . $this->authId . ': ' .
@@ -82,7 +82,7 @@ class sspmod_authcrypt_Auth_Source_Hash extends sspmod_core_Auth_UserPassBase {
 		foreach($this->users as $userpass=>$attrs) {
 			$matches = explode(':', $userpass, 2);
 			if ($matches[0] === $username) {
-				if(SimpleSAML_Utils_Crypto::pwValid($matches[1], $password)) {
+				if(SimpleSAML\Utils\Crypto::pwValid($matches[1], $password)) {
 					return $this->users[$userpass];
 				} else {
 					SimpleSAML_Logger::debug('Incorrect password "' . $password . '" for user '. $username);
