@@ -3,7 +3,7 @@
 /**
  * Give a warning to the user if we receive multiple requests in a short time.
  *
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 class sspmod_core_Auth_Process_WarnShortSSOInterval extends SimpleSAML_Auth_ProcessingFilter {
 
@@ -28,7 +28,7 @@ class sspmod_core_Auth_Process_WarnShortSSOInterval extends SimpleSAML_Auth_Proc
 
 		$timeDelta = time() - $state['PreviousSSOTimestamp'];
 		if ($timeDelta >= 10) {
-			/* At least 10 seconds since last attempt. */
+			// At least 10 seconds since last attempt
 			return;
 		}
 
@@ -43,12 +43,10 @@ class sspmod_core_Auth_Process_WarnShortSSOInterval extends SimpleSAML_Auth_Proc
 			' seconds since last SSO for this user from the SP ' .
 			var_export($entityId, TRUE));
 
-		/* Save state and redirect. */
+		// Save state and redirect
 		$id = SimpleSAML_Auth_State::saveState($state, 'core:short_sso_interval');
 		$url = SimpleSAML_Module::getModuleURL('core/short_sso_interval.php');
-		SimpleSAML_Utilities::redirectTrustedURL($url, array('StateId' => $id));
+		\SimpleSAML\Utils\HTTP::redirectTrustedURL($url, array('StateId' => $id));
 	}
 
 }
-
-?>
\ No newline at end of file
