@@ -6,7 +6,7 @@
  * - 'target': Target URL.
  * - 'params': Parameters which should be included in the request.
  *
- * @package simpleSAMLphp
+ * @package SimpleSAMLphp
  */
 
 
@@ -25,6 +25,11 @@ $this->includeAtTemplateBase('includes/header.php');
 		}
 	?>
 	<p><?php echo $this->t('{core:short_sso_interval:warning}'); ?></p>
+    <div class="trackidtext"><p>
+        <?php echo $this->t('{errors:report_trackid}'); ?>
+        <span class="trackid"><?php echo $this->data['trackId']; ?></span>
+        </p>
+    </div>
 
 	<input type="submit" name="continue" id="contbutton" value="<?php echo htmlspecialchars($this->t('{core:short_sso_interval:retry}')) ?>" />
 
@@ -33,4 +38,3 @@ $this->includeAtTemplateBase('includes/header.php');
 
 <?php
 $this->includeAtTemplateBase('includes/footer.php');
-?>
