@@ -77,6 +77,8 @@ $t->data['username'] = $username;
 $t->data['forceUsername'] = FALSE;
 $t->data['rememberUsernameEnabled'] = $source->getRememberUsernameEnabled();
 $t->data['rememberUsernameChecked'] = $source->getRememberUsernameChecked();
+$t->data['rememberMeEnabled'] = false;
+$t->data['rememberMeChecked'] = false;
 if (isset($_COOKIE[$source->getAuthId() . '-username'])) $t->data['rememberUsernameChecked'] = TRUE;
 $t->data['errorcode'] = $errorCode;
 $t->data['errorparams'] = $errorParams;
