@@ -2,15 +2,15 @@
 <?php
 
 /*
- * This script can be used to generate metadata for simpleSAMLphp
+ * This script can be used to generate metadata for SimpleSAMLphp
  * based on an XML metadata file.
  */
 
 
-/* This is the base directory of the simpleSAMLphp installation. */
+// This is the base directory of the SimpleSAMLphp installation
 $baseDir = dirname(dirname(dirname(dirname(__FILE__))));
 
-/* Add library autoloader. */
+// Add library autoloader.
 require_once($baseDir . '/lib/_autoload.php');
 
 SimpleSAML_Session::useTransientSession(); /* No need to try to create a session here. */
@@ -23,7 +23,8 @@ if(!SimpleSAML_Module::isModuleEnabled('metarefresh')) {
 }
 
 /* Initialize the configuration. */
-SimpleSAML_Configuration::setConfigDir($baseDir . '/config');
+$configdir = SimpleSAML\Utils\Config::getConfigDir();
+SimpleSAML_Configuration::setConfigDir($configdir);
 
 /* $outputDir contains the directory we will store the generated metadata in. */
 $outputDir = $baseDir . '/metadata-generated';
@@ -34,6 +35,11 @@ $outputDir = $baseDir . '/metadata-generated';
  */
 $toStdOut = FALSE;
 
+/* $certificates contains the certificates which should be used to check the signature of the signed
+ * EntityDescriptor in the metadata, or NULL if signature verification shouldn't be done.
+ */
+$certificates = NULL;
+
 /* $validateFingerprint contains the fingerprint of the certificate which should have been used
  * to sign the EntityDescriptor in the metadata, or NULL if fingerprint validation shouldn't be
  * done.
@@ -78,6 +84,14 @@ foreach($argv as $a) {
 	}
 
 	switch($a) {
+	case '--certificate':
+		if($v === NULL || strlen($v) === 0) {
+			echo('The --certficate option requires an parameter.' . "\n");
+			echo('Please run `' . $progName . ' --help` for usage information.' . "\n");
+			exit(1);
+		}
+		$certificates[] = $v;
+		break;
 	case '--validate-fingerprint':
 		if($v === NULL || strlen($v) === 0) {
 			echo('The --validate-fingerprint option requires an parameter.' . "\n");
@@ -120,6 +134,7 @@ $metaloader = new sspmod_metarefresh_MetaLoader();
 
 foreach($files as $f) {
 	$source = array('src' => $f);
+	if (isset($certificates)) $source['certificates'] = $certificates;
 	if (isset($validateFingerprint)) $source['validateFingerprint'] = $validateFingerprint;
 	$metaloader->loadSource($source);
 }
@@ -130,8 +145,6 @@ if($toStdOut) {
 	$metaloader->writeMetadataFiles($outputDir);
 }
 
-exit(0);
-
 /**
  * This function prints the help output.
  */
@@ -145,6 +158,12 @@ function printHelp() {
 	echo('be added to the metadata files in metadata/.' . "\n");
 	echo("\n");
 	echo('Options:' . "\n");
+	echo(' --certificate=<FILE>         The certificate which should be used' . "\n");
+	echo('                              to check the signature of the metadata.' . "\n");
+	echo('                              The file are stored in the cert dir.' . "\n");
+	echo('                              It is possibility to add multiple' . "\n");
+	echo('                              --certificate options to handle' . "\n");
+	echo('                              key rollover.' . "\n");
 	echo(' --validate-fingerprint=<FINGERPRINT>' . "\n");
 	echo('                              Check the signature of the metadata,' . "\n");
 	echo('                              and check the fingerprint of the' . "\n");
@@ -152,14 +171,9 @@ function printHelp() {
 	echo(' -h, --help                   Print this help.' . "\n");
 	echo(' -o=<DIR>, --out-dir=<DIR>    Write the output to this directory. The' . "\n");
 	echo('                              default directory is metadata-generated/.' . "\n");
-	echo('                              Path will be relative to the simpleSAMLphp' . "\n");
+	echo('                              Path will be relative to the SimpleSAMLphp' . "\n");
 	echo('                              base directory.' . "\n");
 	echo(' -s, --stdout                 Write the output to stdout instead of' . "\n");
 	echo('                              seperate files in the output directory.' . "\n");
 	echo("\n");
 }
-
-
-
-
-
