@@ -44,7 +44,8 @@ function SimpleSAML_exception_handler($exception)
         $e->show();
     } else {
         if (class_exists('Error') && $exception instanceof Error) {
-            $errno = $exception->getCode();
+            $code = $exception->getCode();
+            $errno = ($code > 0) ? $code : E_ERROR;
             $errstr = $exception->getMessage();
             $errfile = $exception->getFile();
             $errline = $exception->getLine();
